@@ -58,18 +58,16 @@ OC.L10N.register(
     "Accept" : "Aceptar",
     "Decline" : "Declinar",
     "Tentative" : "Tentativo",
-    "Send email" : "Enviar correo electrónico",
+    "Attendees" : "Asistentes",
     "All day" : "Todo el día",
     "Repeat" : "Repetir",
     "never" : "nunca",
     "after" : "después",
     "available" : "disponible",
-    "More" : "Más",
     "Global" : "Global",
     "Subscribe" : "Suscribir",
     "Personal" : "Personal",
     "Details" : "Detalles",
-    "Attendees" : "Asistentes",
     "Resources" : "Recursos",
     "Close" : "Cerrar",
     "Anniversary" : "Aniversario",
@@ -83,9 +81,6 @@ OC.L10N.register(
     "Status" : "Estatus",
     "Confirmed" : "Confirmado",
     "Categories" : "Categorías",
-    "Talk" : "Hablar",
-    "Mail" : "Correo",
-    "Birthday" : "Fecha de nacimiento",
     "User not found" : "No se encontró el usuario"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
