@@ -7,17 +7,17 @@ OC.L10N.register(
     "Open »%s«" : "Abrir »%s«",
     "Cheers!" : "¡Saludos!",
     "Upcoming events" : "Próximos eventos",
+    "No upcoming events" : "No hay eventos próximos",
     "Calendar" : "Calendario",
     "Appointments" : "Citas",
     "Confirm" : "Confirmar",
     "Where:" : "Dónde:",
-    "Anniversary" : "Aniversario",
-    "Personal" : "Personal",
     "A Calendar app for Nextcloud" : "Una aplicación de Calendario para Nextcloud",
     "Today" : "Hoy",
     "Day" : "Día",
     "Week" : "Semana",
     "Month" : "Mes",
+    "Year" : "Año",
     "List" : "Lista",
     "Preview" : "Previsualizar",
     "Copy link" : "Copiar liga",
@@ -31,6 +31,7 @@ OC.L10N.register(
     "Delete permanently" : "Borrar permanentemente",
     "Empty trash bin" : "Vaciar la papelera de reciclaje",
     "Internal link" : "Enlace interno",
+    "Copy internal link" : "Copiar enlace interno",
     "Share link" : "Compartir liga",
     "Copy public link" : "Copiar enlace público",
     "can edit" : "puede editar",
@@ -38,13 +39,18 @@ OC.L10N.register(
     "Save" : "Guardar",
     "Filename" : "Nombre del archivo",
     "Cancel" : "Cancelar",
+    "Invalid location selected" : "Ubicación seleccionada inválida",
     "Automatic" : "Automático",
     "or" : "o",
     "List view" : "Vista de lista",
     "Actions" : "Acciones",
     "Show week numbers" : "Mostrar número de semana",
+    "Personal availability settings" : "Configuración de disponibilidad personal",
+    "_{duration} minute_::_{duration} minutes_" : ["{duration} minuto","{duration} minutos","{duration} minutos"],
+    "0 minutes" : "0 minutos",
     "Location" : "Ubicación",
     "Description" : "Descripción",
+    "Visibility" : "Visibilidad",
     "Duration" : "Duración",
     "to" : "para",
     "Add" : "Agregar",
@@ -59,31 +65,37 @@ OC.L10N.register(
     "Your email address" : "Tu dirección de correo electrónico",
     "Notification" : "Notificación",
     "Email" : "Correo electrónico",
+    "_minute_::_minutes_" : ["minuto","minutos","minutos"],
     "Add from Files" : "Agregar desde Archivos",
     "Delete file" : "Borrar archivo",
     "Choose a file to add as attachment" : "Selecciona el archivo a agregar como adjunto",
     "Available" : "Disponible",
+    "Not available" : "No disponible",
+    "Checking availability" : "Comprobando disponibilidad",
+    "Availability of attendees, resources and rooms" : "Disponibilidad de asistentes, recursos y salas",
+    "Done" : "Terminado",
     "Unknown" : "Desconocido",
     "Accept" : "Aceptar",
     "Decline" : "Rechazar",
     "Tentative" : "Tentativo",
-    "Send email" : "Enviar correo electrónico",
+    "Attendees" : "Asistentes",
+    "Remove group" : "Eliminar grupo",
+    "Search for emails, users, contacts or groups" : "Buscar correos electrónicos, usuarios, contactos o grupos",
     "All day" : "Todo el día",
     "Repeat" : "Repetir",
     "never" : "nunca",
     "after" : "después",
     "available" : "disponible",
-    "More" : "Más",
     "Pick a time" : "Elige una hora",
     "Pick a date" : "Elige una fecha",
     "Global" : "Global",
     "Subscribe" : "Suscríbete",
-    "No upcoming events" : "No hay eventos próximos",
+    "Personal" : "Personal",
     "Create a new event" : "Crear un nuevo evento",
     "Details" : "Detalles",
-    "Attendees" : "Asistentes",
     "Resources" : "Recursos",
     "Close" : "Cerrar",
+    "Anniversary" : "Aniversario",
     "Week {number} of {year}" : "Semana {number} de {year}",
     "Daily" : "Diariamente",
     "Weekly" : "Semanalmente",
@@ -95,16 +107,6 @@ OC.L10N.register(
     "Confirmed" : "Confirmado",
     "Canceled" : "Cancelada",
     "Categories" : "Categorías",
-    "Money" : "Dinero",
-    "Presentation" : "Presentación",
-    "Talk" : "Hablar",
-    "Office" : "Office",
-    "Mail" : "Correo",
-    "Driving" : "Conducir",
-    "Biking" : "Ciclismo",
-    "Health" : "Salud",
-    "Running" : "Correr",
-    "Birthday" : "Fecha de nacimiento",
     "User not found" : "No se encontró el usuario"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
