@@ -55,18 +55,16 @@ OC.L10N.register(
     "Accept" : "ยอมรับ",
     "Decline" : "ปฏิเสธ",
     "Tentative" : "ชั่วคราว",
-    "Send email" : "ส่งอีเมล",
+    "Attendees" : "ผู้เข้าร่วมกิจกรรม",
     "Remove group" : "ลบกลุ่ม",
     "Repeat" : "ทำซ้ำ",
     "never" : "ไม่ต้องเลย",
     "after" : "หลังจาก",
-    "More" : "เพิ่มเติม",
     "Pick a date" : "เลือกวันที่",
     "Global" : "ทั่วไป",
     "Subscribe" : "สมัครรับข้อมูล",
     "Personal" : "ส่วนตัว",
     "Details" : "รายละเอียด",
-    "Attendees" : "ผู้เข้าร่วมกิจกรรม",
     "Resources" : "ทรัพยากร",
     "Close" : "ปิด",
     "Anniversary" : "วันครบรอบ",
@@ -79,11 +77,6 @@ OC.L10N.register(
     "When shared hide this event" : "เมื่อแชร์จะซ่อนกิจกรรมนี้",
     "Status" : "สถานะ",
     "Confirmed" : "ยืนยันแล้ว",
-    "Categories" : "หมวดหมู่",
-    "Commuting" : "กำลังเดินทาง",
-    "Presentation" : "งานนำเสนอ",
-    "Office" : "สำนักงาน",
-    "Mail" : "จดหมาย",
-    "Birthday" : "วันเกิด"
+    "Categories" : "หมวดหมู่"
 },
 "nplurals=1; plural=0;");
