@@ -31,6 +31,7 @@ use OCA\Calendar\Db\AppointmentConfig;
 use OCA\Calendar\Db\Booking;
 use OCA\Calendar\Exception\ServiceException;
 use OCP\Defaults;
+use OCP\IConfig;
 use OCP\IDateTimeFormatter;
 use OCP\IL10N;
 use OCP\IURLGenerator;
@@ -72,7 +73,8 @@ class MailService {
 		IURLGenerator $urlGenerator,
 		IDateTimeFormatter $dateFormatter,
 		IFactory $lFactory,
-		IManager $notificationManager) {
+		IManager $notificationManager,
+		private IConfig $userConfig) {
 		$this->userManager = $userManager;
 		$this->mailer = $mailer;
 		$this->l10n = $l10n;
@@ -230,7 +232,7 @@ class MailService {
 	private function addBulletList(IEMailTemplate $template,
 		IL10N $l10n,
 		Booking $booking,
-		AppointmentConfig $config):void {
+		AppointmentConfig $config): void {
 		$template->addBodyListItem($booking->getDisplayName(), $l10n->t('Appointment for:'));
 
 		$l = $this->lFactory->findGenericLanguage();
@@ -272,10 +274,9 @@ class MailService {
 		return \OCP\Util::getDefaultEmailAddress('appointments-noreply');
 	}
 
-	public function sendOrganizerBookingInformationEmail(Booking $booking, AppointmentConfig $config, string $calendar) {
+	public function sendOrganizerBookingInformationEmail(Booking $booking, AppointmentConfig $config, string $calendar): void {
 		/** @var IUser $user */
 		$user = $this->userManager->get($config->getUserId());
-
 		if ($user === null) {
 			throw new ServiceException('Could not find organizer');
 		}
@@ -295,12 +296,14 @@ class MailService {
 		$template = $this->mailer->createEMailTemplate('calendar.confirmOrganizer');
 		$template->addHeader();
 
+		$lang = $this->userConfig->getUserValue($user->getUID(), 'core', 'lang', null);
+		$l10n = $this->lFactory->get('calendar', $lang);
 		// Subject
-		$subject = $this->l10n->t('You have a new appointment booking "%s" from %s', [$config->getName(), $booking->getDisplayName()]);
+		$subject = $l10n->t('You have a new appointment booking "%s" from %s', [$config->getName(), $booking->getDisplayName()]);
 		$template->setSubject($subject);
 
 		// Heading
-		$summary = $this->l10n->t('Dear %s, %s (%s) booked an appointment with you.', [$user->getDisplayName(), $booking->getDisplayName(), $booking->getEmail()]);
+		$summary = $l10n->t('Dear %s, %s (%s) booked an appointment with you.', [$user->getDisplayName(), $booking->getDisplayName(), $booking->getEmail()]);
 		$template->addHeading($summary);
 
 		$template->addBodyListItem($booking->getDisplayName() . ' (' . $booking->getEmail() . ')', 'Appointment with:');
@@ -309,7 +312,7 @@ class MailService {
 		}
 
 		// Create Booking overview
-		$this->addBulletList($template, $this->l10n, $booking, $config);
+		$this->addBulletList($template, $l10n, $booking, $config);
 		$template->addFooter();
 
 		$attachment = $this->mailer->createAttachment($calendar, 'appointment.ics', 'text/calendar');
